pub enum WaitError {
Closed,
Lagged(u64),
}Expand description
Error returned when a subscriber cannot receive a leader result.
Variants
Closed
The broadcast channel closed before an outcome was available.
Lagged(u64)
The subscriber lagged behind the broadcast channel.